@@ -40,22 +40,41 @@ G_BEGIN_DECLS
 
 /**
  * GstBinFlags:
- * @GST_BIN_FLAG_NO_RESYNC: don't resync a state change when elements are
- *             added or linked in the bin (Since 1.0.5)
- * @GST_BIN_FLAG_STREAMS_AWARE: Indicates whether the bin can handle elements
- *             that add/remove source pads at any point in time without
- *             first posting a no-more-pads signal (Since 1.10)
  * @GST_BIN_FLAG_LAST: the last enum in the series of flags for bins.
  * Derived classes can use this as first value in a list of flags.
  *
  * GstBinFlags are a set of flags specific to bins. Most are set/used
- * internally. They can be checked using the GST_OBJECT_FLAG_IS_SET () macro,
- * and (un)set using GST_OBJECT_FLAG_SET () and GST_OBJECT_FLAG_UNSET ().
+ * internally. They can be checked using the GST_OBJECT_FLAG_IS_SET() macro,
+ * and (un)set using GST_OBJECT_FLAG_SET() and GST_OBJECT_FLAG_UNSET().
  */
 typedef enum {
+  /**
+   * GST_BIN_FLAG_NO_RESYNC:
+   *
+   * Don't resync a state change when elements are added or linked in the bin
+   *
+   * Since: 1.0.5
+   */
   GST_BIN_FLAG_NO_RESYNC	= (GST_ELEMENT_FLAG_LAST << 0),
+
+  /**
+   * GST_BIN_FLAG_STREAMS_AWARE:
+   *
+   * Indicates whether the bin can handle elements that add/remove source pads
+   * at any point in time without first posting a no-more-pads signal.
+   *
+   * Since: 1.10
+   */
   GST_BIN_FLAG_STREAMS_AWARE	= (GST_ELEMENT_FLAG_LAST << 1),
+
   /* padding */
+
+  /**
+   * GST_BIN_FLAG_LAST:
+   *
+   * The last enum in the series of flags for bins. Derived classes can use this
+   * as first value in a list of flags.
+   */
   GST_BIN_FLAG_LAST		= (GST_ELEMENT_FLAG_LAST << 5)
 } GstBinFlags;
 
@@ -85,7 +104,7 @@ typedef struct _GstBinPrivate GstBinPrivate;
  * GST_BIN_CHILDREN:
  * @bin: a #GstBin
  *
- * Gets the list with children in a bin.
+ * Gets the list of children in a bin.
  */
 #define GST_BIN_CHILDREN(bin)		(GST_BIN_CAST(bin)->children)
 /**
@@ -141,26 +160,18 @@ struct _GstBin {
 /**
  * GstBinClass:
  * @parent_class: bin parent class
- * @add_element: method to add an element to a bin
- * @remove_element: method to remove an element from a bin
- * @handle_message: method to handle a message from the children
- * @deep_element_added: method called when an element was added somewhere
- *     in the bin hierarchy
- * @deep_element_removed: method called when an element was removed somewhere
- *     in the bin hierarchy
  *
- * Subclasses can override the @add_element and @remove_element to
- * update the list of children in the bin.
+ * Subclasses can override #GstBinClass::add_element and #GstBinClass::remove_element
+ * to update the list of children in the bin.
  *
- * The @handle_message method can be overridden to implement custom
- * message handling.  @handle_message takes ownership of the message, just like
- * #gst_element_post_message.
+ * The #GstBinClass::handle_message method can be overridden to implement custom
+ * message handling.
  *
- * The @deep_element_added vfunc will be called when a new element has been
+ * #GstBinClass::deep_element_added will be called when a new element has been
  * added to any bin inside this bin, so it will also be called if a new child
  * was added to a sub-bin of this bin. #GstBin implementations that override
  * this message should chain up to the parent class implementation so the
- * element-added-deep signal is emitted on all parents.
+ * #GstBin::deep-element-added signal is emitted on all parents.
  */
 struct _GstBinClass {
   GstElementClass parent_class;
@@ -169,14 +180,57 @@ struct _GstBinClass {
   GThreadPool  *pool; /* deprecated */
 
   /* signals */
+
+  /**
+   * GstBinClass::element_added:
+   * @bin: the #GstBin
+   * @child: the element that was added
+   *
+   * Method called when an element was added to the bin.
+   */
   void		(*element_added)	(GstBin *bin, GstElement *child);
+
+  /**
+   * GstBinClass::element_removed:
+   * @bin: the #GstBin
+   * @child: the element that was removed
+   *
+   * Method called when an element was removed from the bin.
+   */
   void		(*element_removed)	(GstBin *bin, GstElement *child);
 
   /*< public >*/
   /* virtual methods for subclasses */
+
+  /**
+   * GstBinClass::add_element:
+   * @bin: the #GstBin
+   * @element: the element to be added
+   *
+   * Method to add an element to the bin.
+   *
+   * Returns: %TRUE if the @element was added
+   */
   gboolean	(*add_element)		(GstBin *bin, GstElement *element);
+
+  /**
+   * GstBinClass::remove_element:
+   * @bin: the #GstBin
+   * @element: the element to be removed
+   *
+   * Method to remove an element from the bin.
+   *
+   * Returns: %TRUE if the @element was removed
+   */
   gboolean	(*remove_element)	(GstBin *bin, GstElement *element);
 
+  /**
+   * GstBinClass::handle_message:
+   * @bin: the #GstBin
+   * @message: (transfer full): the message to be handled
+   *
+   * Method to handle a message from the children.
+   */
   void		(*handle_message)	(GstBin *bin, GstMessage *message);
 
   /*< private >*/
@@ -185,7 +239,25 @@ struct _GstBinClass {
 
   /*< public >*/
   /* signal */
+
+  /**
+   * GstBinClass::deep_element_added:
+   * @bin: the top level #GstBin
+   * @sub_bin: the #GstBin to which the element was added
+   * @child: the element that was added
+   *
+   * Method called when an element was added somewhere in the bin hierarchy.
+   */
   void          (*deep_element_added)   (GstBin *bin, GstBin *sub_bin, GstElement *child);
+
+  /**
+   * GstBinClass::deep_element_removed:
+   * @bin: the top level #GstBin
+   * @sub_bin: the #GstBin from which the element was removed
+   * @child: the element that was removed
+   *
+   * Method called when an element was removed somewhere in the bin hierarchy.
+   */
   void          (*deep_element_removed) (GstBin *bin, GstBin *sub_bin, GstElement *child);
 
   /*< private >*/
@@ -196,7 +268,7 @@ GST_API
 GType		gst_bin_get_type		(void);
 
 GST_API
-GstElement*	gst_bin_new			(const gchar *name);
+GstElement*	gst_bin_new			(const gchar *name) G_GNUC_WARN_UNUSED_RESULT;
 
 /* add and remove elements from the bin */
 
@@ -209,33 +281,36 @@ gboolean	gst_bin_remove			(GstBin *bin, GstElement *element);
 /* retrieve a single child */
 
 GST_API
-GstElement*	gst_bin_get_by_name		 (GstBin *bin, const gchar *name);
+GstElement*	gst_bin_get_by_name		 (GstBin *bin, const gchar *name) G_GNUC_WARN_UNUSED_RESULT;
 
 GST_API
-GstElement*	gst_bin_get_by_name_recurse_up	 (GstBin *bin, const gchar *name);
+GstElement*	gst_bin_get_by_name_recurse_up	 (GstBin *bin, const gchar *name) G_GNUC_WARN_UNUSED_RESULT;
 
 GST_API
-GstElement*	gst_bin_get_by_interface	 (GstBin *bin, GType iface);
+GstElement*	gst_bin_get_by_interface	 (GstBin *bin, GType iface) G_GNUC_WARN_UNUSED_RESULT;
 
 /* retrieve multiple children */
 
 GST_API
-GstIterator*    gst_bin_iterate_elements	 (GstBin *bin);
+GstIterator*    gst_bin_iterate_elements	 (GstBin *bin) G_GNUC_WARN_UNUSED_RESULT;
 
 GST_API
-GstIterator*    gst_bin_iterate_sorted		 (GstBin *bin);
+GstIterator*    gst_bin_iterate_sorted		 (GstBin *bin) G_GNUC_WARN_UNUSED_RESULT;
 
 GST_API
-GstIterator*    gst_bin_iterate_recurse		 (GstBin *bin);
+GstIterator*    gst_bin_iterate_recurse		 (GstBin *bin) G_GNUC_WARN_UNUSED_RESULT;
 
 GST_API
-GstIterator*	gst_bin_iterate_sinks		 (GstBin *bin);
+GstIterator*	gst_bin_iterate_sinks		 (GstBin *bin) G_GNUC_WARN_UNUSED_RESULT;
 
 GST_API
-GstIterator*	gst_bin_iterate_sources		 (GstBin *bin);
+GstIterator*	gst_bin_iterate_sources		 (GstBin *bin) G_GNUC_WARN_UNUSED_RESULT;
 
 GST_API
-GstIterator*	gst_bin_iterate_all_by_interface (GstBin *bin, GType iface);
+GstIterator*	gst_bin_iterate_all_by_interface (GstBin *bin, GType iface) G_GNUC_WARN_UNUSED_RESULT;
+
+GST_API
+GstIterator*	gst_bin_iterate_all_by_element_factory_name (GstBin * bin, const gchar * factory_name) G_GNUC_WARN_UNUSED_RESULT;
 
 /* latency */
 
@@ -250,9 +325,7 @@ void            gst_bin_set_suppressed_flags (GstBin * bin, GstElementFlags flag
 GST_API
 GstElementFlags gst_bin_get_suppressed_flags (GstBin * bin);
 
-#ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstBin, gst_object_unref)
-#endif
 
 G_END_DECLS
 
